==> phpsysinfo_2.5.1.orig.tar.gz: phpsysinfo/includes/lang/pa_utf8.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: pa_utf8.php,v 1.2 2005/12/07 15:02:11 bigmichi1 Exp $

$charset		= 'utf-8';

$text['title']          = 'ਸਿਸਟਮ ਜਾਣਕਾਰੀ';

$text['vitals']         = 'ਸਿਸਟਮ ਮਾਰਕਮ';
$text['hostname']       = 'ਮੇਜ਼ਬਾਨ ਨਾਂ';
$text['ip']             = 'ਸੁਣਨ IP';
$text['kversion']       = 'ਕਰਨਲ ਵਰਜਨ';
$text['dversion']       = 'ਵੰਡ ਨਾਂ';
$text['uptime']         = 'ਚੱਲਣ ਸਮਾਂ';
$text['users']          = 'ਕੁੱਲ ਉਪਭੋਗੀ';
$text['loadavg']        = 'ਔਸਤ ਲੋਡ';

$text['hardware']       = 'ਜੰਤਰ ਜਾਣਕਾਰੀ';
$text['numcpu']         = 'ਪਰੋਸੈਸਰ';
$text['cpumodel']       = 'ਮਾਡਲ';
$text['cpuspeed']       = 'CPU ਗਤੀ';
$text['busspeed']       = 'ਬਸ ਗਤੀ';
$text['cache']          = 'ਕੈਂਚੇ ਅਕਾਰ';
$text['bogomips']       = 'ਸਿਸਟਮ Bogomips';

$text['pci']            = 'PCI ਜੰਤਰ';
$text['ide']            = 'IDE ਜੰਤਰ';
$text['scsi']           = 'SCSI ਜੰਤਰ';
$text['usb']            = 'USB ਜੰਤਰ';

$text['netusage']       = 'ਨੈੱਟਵਰਕ ਵਰਤੋਂ';
$text['device']         = 'ਜੰਤਰ';
$text['received']       = 'ਪਰਾਪਤ ਹੋਇਆ';
$text['sent']           = 'ਭੇਜਿਆ';
$text['errors']         = 'ਗਲਤੀ/ਸੁੱਟੇ';

$text['connections']    = 'ਸਥਾਪਤ ਨੈੱਟਵਰਕ ਕੁਨੈਕਸ਼ਨ';

$text['memusage']       = 'ਮੈਮੋਰੀ ਵਰਤੋਂ';
$text['phymem']         = 'ਭੌਤਿਕ ਮੈਮੋਰੀ';
$text['swap']           = 'ਡਿਸਕ ਸਵੈਪ';

$text['fs']             = 'ਮਾਊਂਟ ਕੀਤੇ ਫਾਇਲ ਸਿਸਟਮ';
$text['mount']          = 'ਮਾਊਂਟ';
$text['partition']      = 'ਭਾਗ';

$text['percent']        = 'ਫ਼ੀ-ਸਦੀ ਸਮੱਰਥਾ';
$text['type']           = 'ਕਿਸਮ';
$text['free']           = 'ਮੁਕਤ (ਖਾਲੀ)';
$text['used']           = 'ਵਰਤੀ';
$text['size']           = 'ਅਕਾਰ';
$text['totals']         = 'ਕੁੱਲ';

$text['kb']             = 'ਕਿਬਾ';
$text['mb']             = 'ਮੈਬਾ';
$text['gb']             = 'ਗੈਬਾ';

$text['none']           = 'ਕੋਈ ਨਹੀਂ';

$text['capacity']       = 'ਸਮੱਰਥਾ'; 

$text['template']       = 'ਨਮੂਨਾ';
$text['language']       = 'ਭਾਸ਼ਾ';
$text['submit']         = 'ਪੇਸ਼ ਕਰੋੇ';
$text['created']        = 'ਬਣਾਇਆ';
$text['locale']         = 'pa';
$text['gen_time']       = '%b %d, %Y ਨੂੰ %I:%M %p ਵਜੇ';

$text['days']           = 'ਦਿਨ';
$text['hours']          = 'ਘੰਟੇ';
$text['minutes']        = 'ਮਿੰਟ';

$text['temperature']    = 'ਤਾਪਮਾਨ';
$text['voltage']        = 'ਵੋਲਟੇਜ਼';
$text['fans']           = 'ਪੱਖੇ';
$text['s_value']        = 'ਮੁੱਲ';
$text['s_min']          = 'ਘੱਟੋ-ਘੱਟ';
$text['s_max']          = 'ਵੱਧੋ-ਵੱਧ';
$text['s_div']          = 'ਡਿਜ';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'ਸੀਮਾ';
$text['s_label']        = 'ਲੇਬਲ';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> phpsysinfo_2.5.2.orig.tar.gz: phpsysinfo/includes/lang/pa_utf8.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: pa_utf8.php,v 1.4 2006/06/05 11:48:16 bigmichi1 Exp $

$charset		= 'utf-8';

$text['title']          = 'ਸਿਸਟਮ ਜਾਣਕਾਰੀ';

$text['vitals']         = 'ਸਿਸਟਮ ਮਾਰਕਮ';
$text['hostname']       = 'ਮੇਜ਼ਬਾਨ ਨਾਂ';
$text['ip']             = 'ਸੁਣਨ IP';
$text['kversion']       = 'ਕਰਨਲ ਵਰਜਨ';
$text['dversion']       = 'ਵੰਡ ਨਾਂ';
$text['uptime']         = 'ਚੱਲਣ ਸਮਾਂ';
$text['users']          = 'ਕੁੱਲ ਉਪਭੋਗੀ';
$text['loadavg']        = 'ਔਸਤ ਲੋਡ';

$text['hardware']       = 'ਜੰਤਰ ਜਾਣਕਾਰੀ';
$text['numcpu']         = 'ਪਰੋਸੈਸਰ';
$text['cpumodel']       = 'ਮਾਡਲ';
$text['cpuspeed']       = 'CPU ਗਤੀ';
$text['busspeed']       = 'ਬਸ ਗਤੀ';
$text['cache']          = 'ਕੈਂਚੇ ਅਕਾਰ';
$text['bogomips']       = 'ਸਿਸਟਮ Bogomips';

$text['pci']            = 'PCI ਜੰਤਰ';
$text['ide']            = 'IDE ਜੰਤਰ';
$text['scsi']           = 'SCSI ਜੰਤਰ';
$text['usb']            = 'USB ਜੰਤਰ';

$text['netusage']       = 'ਨੈੱਟਵਰਕ ਵਰਤੋਂ';
$text['device']         = 'ਜੰਤਰ';
$text['received']       = 'ਪਰਾਪਤ ਹੋਇਆ';
$text['sent']           = 'ਭੇਜਿਆ';
$text['errors']         = 'ਗਲਤੀ/ਸੁੱਟੇ';

$text['connections']    = 'ਸਥਾਪਤ ਨੈੱਟਵਰਕ ਕੁਨੈਕਸ਼ਨ';

$text['memusage']       = 'ਮੈਮੋਰੀ ਵਰਤੋਂ';
$text['phymem']         = 'ਭੌਤਿਕ ਮੈਮੋਰੀ';
$text['swap']           = 'ਡਿਸਕ ਸਵੈਪ';

$text['fs']             = 'ਮਾਊਂਟ ਕੀਤੇ ਫਾਇਲ ਸਿਸਟਮ';
$text['mount']          = 'ਮਾਊਂਟ';
$text['partition']      = 'ਭਾਗ';

$text['percent']        = 'ਫ਼ੀ-ਸਦੀ ਸਮੱਰਥਾ';
$text['type']           = 'ਕਿਸਮ';
$text['free']           = 'ਮੁਕਤ (ਖਾਲੀ)';
$text['used']           = 'ਵਰਤੀ';
$text['size']           = 'ਅਕਾਰ';
$text['totals']         = 'ਕੁੱਲ';

$text['kb']             = 'ਕਿਬਾ';
$text['mb']             = 'ਮੈਬਾ';
$text['gb']             = 'ਗੈਬਾ';

$text['none']           = 'ਕੋਈ ਨਹੀਂ';

$text['capacity']       = 'ਸਮੱਰਥਾ'; 

$text['template']       = 'ਨਮੂਨਾ';
$text['language']       = 'ਭਾਸ਼ਾ';
$text['submit']         = 'ਪੇਸ਼ ਕਰੋੇ';
$text['created']        = 'ਬਣਾਇਆ';
$text['locale']         = 'pa';
$text['gen_time']       = '%b %d, %Y ਨੂੰ %I:%M %p ਵਜੇ';

$text['days']           = 'ਦਿਨ';
$text['hours']          = 'ਘੰਟੇ';
$text['minutes']        = 'ਮਿੰਟ';

$text['temperature']    = 'ਤਾਪਮਾਨ';
$text['voltage']        = 'ਵੋਲਟੇਜ਼';
$text['fans']           = 'ਪੱਖੇ';
$text['s_value']        = 'ਮੁੱਲ';
$text['s_min']          = 'ਘੱਟੋ-ਘੱਟ';
$text['s_max']          = 'ਵੱਧੋ-ਵੱਧ';
$text['s_div']          = 'ਡਿਜ';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'ਸੀਮਾ';
$text['s_label']        = 'ਲੇਬਲ';
$text['degreeC']        = '&ordm;C';
$text['degreeF']        = '&ordm;F';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

$text['app']            = 'Kernel + applications';
$text['buffers']        = 'Buffers';
$text['cached']         = 'Cached';

?>
